summaryrefslogtreecommitdiffstats
path: root/sys/cddl/contrib/opensolaris/uts/common/fs/zfs/spa_history.c
diff options
context:
space:
mode:
authorjamie <jamie@FreeBSD.org>2009-06-13 15:39:12 +0000
committerjamie <jamie@FreeBSD.org>2009-06-13 15:39:12 +0000
commitf419891544e311aa974e0648e0455a9de14ea0fa (patch)
treef9cfb93ff7fc2f89561efcde362151b31946e095 /sys/cddl/contrib/opensolaris/uts/common/fs/zfs/spa_history.c
parentdbcc94be36eb7e16660d9d09b9885c37b7e22d1d (diff)
downloadFreeBSD-src-f419891544e311aa974e0648e0455a9de14ea0fa.zip
FreeBSD-src-f419891544e311aa974e0648e0455a9de14ea0fa.tar.gz
Rename the host-related prison fields to be the same as the host.*
parameters they represent, and the variables they replaced, instead of abbreviated versions of them. Approved by: bz (mentor)
Diffstat (limited to 'sys/cddl/contrib/opensolaris/uts/common/fs/zfs/spa_history.c')
-rw-r--r--sys/cddl/contrib/opensolaris/uts/common/fs/zfs/spa_history.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/sys/cddl/contrib/opensolaris/uts/common/fs/zfs/spa_history.c b/sys/cddl/contrib/opensolaris/uts/common/fs/zfs/spa_history.c
index 8e20c4d..de520d3 100644
--- a/sys/cddl/contrib/opensolaris/uts/common/fs/zfs/spa_history.c
+++ b/sys/cddl/contrib/opensolaris/uts/common/fs/zfs/spa_history.c
@@ -179,9 +179,9 @@ static char *
spa_history_zone()
{
#ifdef _KERNEL
/* XXX: pr_host can be changed by default from within a jail! */
if (jailed(curthread->td_ucred))
- return (curthread->td_ucred->cr_prison->pr_host);
+ return (curthread->td_ucred->cr_prison->pr_hostname);
#endif
return ("global");
}
@@ -179,9 +179,9 @@ static char *
{
#ifdef _KERNEL
- /* XXX: pr_host can be changed by default from within a jail! */
+ /* XXX: pr_hostname can be changed by default from within a jail! */
if (jailed(curthread->td_ucred))
OpenPOWER on IntegriCloud